@@ -1,3 +1,4 @@
+//go:build tools
 // +build tools
 
 package toolimports
@@ -8,6 +9,5 @@ package toolimports
 
 import (
 	_ "github.com/golangci/golangci-lint/cmd/golangci-lint"
-	_ "honnef.co/go/tools/cmd/staticcheck"
 	_ "k8s.io/cli-runtime/pkg/resource" // This is imported because we want to be able to require it at a certain version, since otherwise Helm breaks.
 )
